@@ -4,6 +4,7 @@ from pathlib import Path
 
 import pytest
 import ppx
+from cloudpathlib import CloudPath
 
 PXID = "PXD000001"
 
@@ -42,3 +43,17 @@ def test_change_dir(monkeypatch, tmp_path):
 
     proj = ppx.PrideProject(PXID)
     assert proj.local == test_dir / PXID
+
+
+def test_cloud(monkeypatch, cloud_bucket):
+    """Test a cloud location"""
+    test_bucket = "s3://ppx-test-bucket/ppx"
+    ppx.set_data_dir(test_bucket)
+    assert ppx.get_data_dir() == CloudPath(test_bucket)
+
+    ppx.set_data_dir()  # reset it.
+    assert ppx.get_data_dir() != CloudPath(test_bucket)
+
+    monkeypatch.setenv("PPX_DATA_DIR", str(test_bucket))
+    ppx.set_data_dir()
+    assert ppx.get_data_dir() == CloudPath(test_bucket)
