@@ -2,12 +2,12 @@
 
 These tests are in a separate file because they all require internet access.
 """
-import filecmp
 from ftplib import FTP, error_temp
 
 import pytest
 import ppx
-import requests
+
+from . import utils
 
 PXID = "PXD000001"
 MSVID = "MSV000087408"
@@ -38,15 +38,15 @@ def test_pride_download(tmp_path):
     txt = proj.download(fname)
     files = proj.local_files()
     local_txt = tmp_path / PXID / fname
-    orig_sig = sig(local_txt)
+    orig_sig = utils.sig(local_txt)
     assert txt == [local_txt]
     assert files[0] == local_txt
 
     txt = proj.download(fname)  # should do nothing
-    assert orig_sig == sig(local_txt)
+    assert orig_sig == utils.sig(local_txt)
 
     txt = proj.download(fname, force_=True)
-    new_size, new_mtime = sig(local_txt)
+    new_size, new_mtime = utils.sig(local_txt)
     assert orig_sig[0] == new_size
     assert orig_sig[1] != new_mtime
 
@@ -92,22 +92,17 @@ def test_massive_download(tmp_path):
     txt = proj.download(fname)
     files = proj.local_files()
     local_txt = tmp_path / MSVID / fname
-    orig_sig = sig(local_txt)
+    orig_sig = utils.sig(local_txt)
     assert txt == [local_txt]
     assert files[0] == local_txt
 
     txt = proj.download(fname)  # should do nothing
-    assert orig_sig == sig(local_txt)
+    assert orig_sig == utils.sig(local_txt)
 
     txt = proj.download(fname, force_=True)
-    new_size, new_mtime = sig(local_txt)
+    new_size, new_mtime = utils.sig(local_txt)
     assert orig_sig[0] == new_size
     assert orig_sig[1] != new_mtime
 
     proj.timeout = 10
     assert proj._parser_state is None
-
-
-def sig(f):
-    st = f.stat()
-    return st.st_size, st.st_mtime
